/****************************************************************************
** Meta object code from reading C++ file 'oxygenframeshadow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../oxygen-6.6.91/kstyle/oxygenframeshadow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'oxygenframeshadow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Oxygen__FrameShadowFactory_t {
    QByteArrayData data[3];
    char stringdata0[44];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__FrameShadowFactory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__FrameShadowFactory_t qt_meta_stringdata_Oxygen__FrameShadowFactory = {
    {
QT_MOC_LITERAL(0, 0, 26), // "Oxygen::FrameShadowFactory"
QT_MOC_LITERAL(1, 27, 15), // "widgetDestroyed"
QT_MOC_LITERAL(2, 43, 0) // ""

    },
    "Oxygen::FrameShadowFactory\0widgetDestroyed\0"
    ""
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__FrameShadowFactory[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QObjectStar,    2,

       0        // eod
};

void Oxygen::FrameShadowFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<FrameShadowFactory *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->widgetDestroyed((*reinterpret_cast< QObject*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::FrameShadowFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__FrameShadowFactory.data,
    qt_meta_data_Oxygen__FrameShadowFactory,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::FrameShadowFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FrameShadowFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__FrameShadowFactory.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Oxygen::FrameShadowFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_Oxygen__FrameShadowBase_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__FrameShadowBase_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__FrameShadowBase_t qt_meta_stringdata_Oxygen__FrameShadowBase = {
    {
QT_MOC_LITERAL(0, 0, 23) // "Oxygen::FrameShadowBase"

    },
    "Oxygen::FrameShadowBase"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__FrameShadowBase[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Oxygen::FrameShadowBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::FrameShadowBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__FrameShadowBase.data,
    qt_meta_data_Oxygen__FrameShadowBase,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::FrameShadowBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FrameShadowBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__FrameShadowBase.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Oxygen::FrameShadowBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Oxygen__SunkenFrameShadow_t {
    QByteArrayData data[1];
    char stringdata0[26];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__SunkenFrameShadow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__SunkenFrameShadow_t qt_meta_stringdata_Oxygen__SunkenFrameShadow = {
    {
QT_MOC_LITERAL(0, 0, 25) // "Oxygen::SunkenFrameShadow"

    },
    "Oxygen::SunkenFrameShadow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__SunkenFrameShadow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Oxygen::SunkenFrameShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::SunkenFrameShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<FrameShadowBase::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__SunkenFrameShadow.data,
    qt_meta_data_Oxygen__SunkenFrameShadow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::SunkenFrameShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::SunkenFrameShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__SunkenFrameShadow.stringdata0))
        return static_cast<void*>(this);
    return FrameShadowBase::qt_metacast(_clname);
}

int Oxygen::SunkenFrameShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FrameShadowBase::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Oxygen__FlatFrameShadow_t {
    QByteArrayData data[1];
    char stringdata0[24];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__FlatFrameShadow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__FlatFrameShadow_t qt_meta_stringdata_Oxygen__FlatFrameShadow = {
    {
QT_MOC_LITERAL(0, 0, 23) // "Oxygen::FlatFrameShadow"

    },
    "Oxygen::FlatFrameShadow"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__FlatFrameShadow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Oxygen::FlatFrameShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::FlatFrameShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<FrameShadowBase::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__FlatFrameShadow.data,
    qt_meta_data_Oxygen__FlatFrameShadow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::FlatFrameShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FlatFrameShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__FlatFrameShadow.stringdata0))
        return static_cast<void*>(this);
    return FrameShadowBase::qt_metacast(_clname);
}

int Oxygen::FlatFrameShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FrameShadowBase::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
