/****************************************************************************
** Meta object code from reading C++ file 'oxygenmenuengine.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../oxygen-6.6.91/kstyle/animations/oxygenmenuengine.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'oxygenmenuengine.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Oxygen__MenuBaseEngine_t {
    QByteArrayData data[1];
    char stringdata0[23];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__MenuBaseEngine_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__MenuBaseEngine_t qt_meta_stringdata_Oxygen__MenuBaseEngine = {
    {
QT_MOC_LITERAL(0, 0, 22) // "Oxygen::MenuBaseEngine"

    },
    "Oxygen::MenuBaseEngine"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__MenuBaseEngine[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void Oxygen::MenuBaseEngine::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::MenuBaseEngine::staticMetaObject = { {
    QMetaObject::SuperData::link<BaseEngine::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__MenuBaseEngine.data,
    qt_meta_data_Oxygen__MenuBaseEngine,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::MenuBaseEngine::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::MenuBaseEngine::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__MenuBaseEngine.stringdata0))
        return static_cast<void*>(this);
    return BaseEngine::qt_metacast(_clname);
}

int Oxygen::MenuBaseEngine::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BaseEngine::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_Oxygen__MenuEngineV1_t {
    QByteArrayData data[4];
    char stringdata0[46];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__MenuEngineV1_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__MenuEngineV1_t qt_meta_stringdata_Oxygen__MenuEngineV1 = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Oxygen::MenuEngineV1"
QT_MOC_LITERAL(1, 21, 16), // "unregisterWidget"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 6) // "object"

    },
    "Oxygen::MenuEngineV1\0unregisterWidget\0"
    "\0object"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__MenuEngineV1[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QObjectStar,    3,

       0        // eod
};

void Oxygen::MenuEngineV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MenuEngineV1 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->unregisterWidget((*reinterpret_cast< QObject*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::MenuEngineV1::staticMetaObject = { {
    QMetaObject::SuperData::link<MenuBaseEngine::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__MenuEngineV1.data,
    qt_meta_data_Oxygen__MenuEngineV1,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::MenuEngineV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::MenuEngineV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__MenuEngineV1.stringdata0))
        return static_cast<void*>(this);
    return MenuBaseEngine::qt_metacast(_clname);
}

int Oxygen::MenuEngineV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MenuBaseEngine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
struct qt_meta_stringdata_Oxygen__MenuEngineV2_t {
    QByteArrayData data[4];
    char stringdata0[46];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__MenuEngineV2_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__MenuEngineV2_t qt_meta_stringdata_Oxygen__MenuEngineV2 = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Oxygen::MenuEngineV2"
QT_MOC_LITERAL(1, 21, 16), // "unregisterWidget"
QT_MOC_LITERAL(2, 38, 0), // ""
QT_MOC_LITERAL(3, 39, 6) // "object"

    },
    "Oxygen::MenuEngineV2\0unregisterWidget\0"
    "\0object"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__MenuEngineV2[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       1,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   19,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QObjectStar,    3,

       0        // eod
};

void Oxygen::MenuEngineV2::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MenuEngineV2 *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->unregisterWidget((*reinterpret_cast< QObject*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::MenuEngineV2::staticMetaObject = { {
    QMetaObject::SuperData::link<MenuBaseEngine::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__MenuEngineV2.data,
    qt_meta_data_Oxygen__MenuEngineV2,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::MenuEngineV2::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::MenuEngineV2::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__MenuEngineV2.stringdata0))
        return static_cast<void*>(this);
    return MenuBaseEngine::qt_metacast(_clname);
}

int Oxygen::MenuEngineV2::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MenuBaseEngine::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
